package it.tecnologieweb.pizza.web.dao.hsqldb;

import it.tecnologieweb.pizza.web.dao.CorsoDAO;
import it.tecnologieweb.pizza.web.dao.CorsoTO;
import it.tecnologieweb.pizza.web.dao.ProfessoreTO;

import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.sql.Statement;
import java.util.ArrayList;
import java.util.List;

public class HsqldbCorsoDAO 
implements CorsoDAO {

	@SuppressWarnings("unchecked")
	public List getCorsi() {
		List corsi = new ArrayList();
		Connection conn = HsqldbDAOFactory.createConnection();
		try {
			Statement stmt = conn.createStatement();
			ResultSet set = stmt.executeQuery(HsqldbQuery.queryCorsi);
			while (set.next()) {
				CorsoTO corso = new CorsoTO();
				corso.setId(set.getInt("id"));
				corso.setNome(set.getString("nome"));
				corso.setAnno(set.getString("anno"));
				corso.setIdProf(set.getInt("idProfessore"));
				corsi.add(corso);
			}
			set.close();
			stmt.close();
		} catch (SQLException e) {
			e.printStackTrace();
			System.out.println("getCorsi: errore");
			HsqldbDAOFactory.closeConnection(conn);
			return corsi;
		}
		HsqldbDAOFactory.closeConnection(conn);
		return corsi;
	}

	public CorsoTO getCorso(Integer id) {
		CorsoTO corso = new CorsoTO();
		ProfessoreTO professore = new ProfessoreTO();
		Connection conn = HsqldbDAOFactory.createConnection();
		try {
			PreparedStatement add_stmt = conn.prepareStatement(HsqldbQuery.queryCorsiId);
			add_stmt.clearParameters();
			add_stmt.setInt(1, id);
			ResultSet set = add_stmt.executeQuery();
			if (set.next()) {
				corso.setId(set.getInt("idCorso"));
				corso.setNome(set.getString("nomeCorso"));
				corso.setAnno(set.getString("anno"));
				// --------------
				professore.setId(set.getInt("id"));
				professore.setNome(set.getString("nome"));
				professore.setCognome(set.getString("cognome"));
				professore.setMatricola(set.getString("matricola"));
				corso.setProfessore(professore);
			}
			set.close();
			add_stmt.close();
		} catch (SQLException e) {
			e.printStackTrace();
			HsqldbDAOFactory.closeConnection(conn);
			return corso;
		}
		HsqldbDAOFactory.closeConnection(conn);
		return corso;
	}

	public int insertCorso(CorsoTO corso) {
		Connection conn = HsqldbDAOFactory.createConnection();
		int i = -1;
		try {
			PreparedStatement add_stmt = conn.prepareStatement(HsqldbQuery.insertCorso);
			add_stmt.clearParameters();
			add_stmt.setString(1, corso.getNome());
			add_stmt.setString(2, corso.getAnno());
			add_stmt.setString(3, corso.getProgramma());
			add_stmt.setInt(4, corso.getProfessore().getId());
			add_stmt.executeUpdate();
			Statement stmt = conn.createStatement();
			ResultSet set = stmt.executeQuery(HsqldbQuery.lastInsertId);
			if (set.next()) {
				i = Long.valueOf(set.getLong(1)).intValue();
			}
			set.close();
			stmt.close();
			add_stmt.close();
		} catch (SQLException e) {
			e.printStackTrace();
			System.out.println("creazione corso fallita");
			HsqldbDAOFactory.closeConnection(conn);
			return i;
		}
		HsqldbDAOFactory.closeConnection(conn);
		return i;
	}

	public void updateCorso(CorsoTO corso) {
		Connection conn = HsqldbDAOFactory.createConnection();
		try {
			PreparedStatement add_stmt = conn.prepareStatement(HsqldbQuery.updateCorso);
			add_stmt.clearParameters();
			add_stmt.setString(1, corso.getNome());
			add_stmt.setString(2, corso.getAnno());
			add_stmt.setString(3, corso.getProgramma());
			add_stmt.setInt(4, corso.getProfessore().getId());
			add_stmt.setInt(5, corso.getId());
			add_stmt.executeUpdate();
			add_stmt.close();
		} catch (SQLException e) {
			e.printStackTrace();
			System.out.println("creazione corso fallita");
			HsqldbDAOFactory.closeConnection(conn);
			return;
		}
		HsqldbDAOFactory.closeConnection(conn);
	}

	public void delCorso(Integer id) {
		Connection conn = HsqldbDAOFactory.createConnection();
		try {
			PreparedStatement add_stmt = conn.prepareStatement(HsqldbQuery.deleteCorso);
			add_stmt.clearParameters();
			add_stmt.setInt(1, id);
			add_stmt.executeUpdate();
			add_stmt.close();
		} catch (SQLException e) {
			e.printStackTrace();
			System.out.println("distruzione corso fallita");
			HsqldbDAOFactory.closeConnection(conn);
			return;
		}
		HsqldbDAOFactory.closeConnection(conn);
	}

	// ------------------------------------------------------------

	/**
	 * Da eseguirsi dopo la init table dei professori
	 */
	public void initTable() {
		Connection conn = HsqldbDAOFactory.createConnection();
		try {
			Statement stmt = conn.createStatement();
			stmt.execute(HsqldbQuery.dropTableCorsi);
			stmt.close();
		} catch (SQLException e) {
			e.printStackTrace();
			System.out.println("tabella corsi non esiste");
		}
		try {
			Statement stmt = conn.createStatement();
			stmt.execute(HsqldbQuery.createTableCorsi);
			System.out.println("tabella corsi creata");
			stmt.close();
		} catch (SQLException e) {
			e.printStackTrace(); // To change body of catch statement use
			System.out.println("tabella corsi esiste gia'"); // Options |
		}
		HsqldbDAOFactory.closeConnection(conn);
	}

}
