package it.tecnologieweb.pizza.web.dao.hsqldb;

import it.tecnologieweb.pizza.web.dao.CorsoTO;
import it.tecnologieweb.pizza.web.dao.ProfessoreDAO;
import it.tecnologieweb.pizza.web.dao.ProfessoreTO;

import java.io.IOException;
import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.sql.Statement;
import java.util.ArrayList;
import java.util.List;

public class HsqldbProfessoreDAO 
implements ProfessoreDAO {
	
	@SuppressWarnings("unchecked")
	public List getProfessori() {
		List professori = new ArrayList();
		Connection conn = HsqldbDAOFactory.createConnection();
		try {
			Statement stmt = conn.createStatement();
			ResultSet set = stmt.executeQuery(HsqldbQuery.queryProfessori);
			while (set.next()) {
				ProfessoreTO professore = new ProfessoreTO();
				professore.setId(set.getInt("id"));
				professore.setNome(set.getString("nome"));
				professore.setCognome(set.getString("cognome"));
				professore.setMatricola(set.getString("matricola"));
				professori.add(professore);
			}
			set.close();
			stmt.close();
		} catch (SQLException e) {
			e.printStackTrace();
			System.out.println("getProfessori: errore");
			HsqldbDAOFactory.closeConnection(conn);
			return professori;
		}
		HsqldbDAOFactory.closeConnection(conn);
		return professori;
	}

	public ProfessoreTO getProfessore(Integer id) {
		ProfessoreTO professore = new ProfessoreTO();
		CorsoTO corso;
		Connection conn = HsqldbDAOFactory.createConnection();
		try {
			PreparedStatement add_stmt = conn.prepareStatement(HsqldbQuery.queryProfessoriID);
			add_stmt.clearParameters();
			add_stmt.setInt(1, id);
			ResultSet set = add_stmt.executeQuery();
			while (set.next()) {
				if (professore.getId() == null) {
					professore.setId(set.getInt("id"));
					professore.setNome(set.getString("nome"));
					professore.setCognome(set.getString("cognome"));
					professore.setMatricola(set.getString("matricola"));
					professore.setBiografia(set.getString("biografia"));
					// A.fotoBytes, A.fotoContentType, A.fotoName
					professore.setFotoBytes(set.getBytes("fotoBytes"));
					professore.setFotoContentType(set
							.getString("fotoContentType"));
					professore.setFotoName(set.getString("fotoName"));
				}
//				if (set.getInt("idCorso") != 0 && set.getString("nomeCorso") != null ) {
				if ( set.getString("nomeCorso") != null ) {
					corso = new CorsoTO();
					corso.setId(set.getInt("idCorso"));
					corso.setNome(set.getString("nomeCorso"));
					corso.setAnno(set.getString("anno"));
					professore.addCorso(corso);
				}
			}
			set.close();
			add_stmt.close();
		} catch (SQLException e) {
			e.printStackTrace();
			HsqldbDAOFactory.closeConnection(conn);
			return null;
		}
		HsqldbDAOFactory.closeConnection(conn);
		return professore;
	}

	public int insertProfessore(ProfessoreTO professore) {
		int i = -1;
		Connection conn = HsqldbDAOFactory.createConnection();
		try {
			PreparedStatement add_stmt = conn.prepareStatement(HsqldbQuery.insertProf);
			// nome, cognome, matricola, biografia, fotoBytes, fotoContentType,
			// fotoName
			add_stmt.clearParameters();
			add_stmt.setString(1, professore.getNome());
			add_stmt.setString(2, professore.getCognome());
			add_stmt.setString(3, professore.getMatricola());
			add_stmt.setString(4, professore.getBiografia());
			if (professore.getFoto() != null) {
				add_stmt.setBytes(5, professore.getFoto().getBytes());
				add_stmt.setString(6, professore.getFoto().getContentType());
				add_stmt.setString(7, professore.getFoto().getName());
			}
			add_stmt.executeUpdate();
			Statement stmt = conn.createStatement();
			ResultSet set = stmt.executeQuery(HsqldbQuery.lastInsertId);
			if (set.next()) {
				i = Long.valueOf(set.getLong(1)).intValue();
			}
			set.close();
			stmt.close();
			add_stmt.close();
		} catch (SQLException e) {
			e.printStackTrace();
			System.out.println("creazione professore fallita");
			HsqldbDAOFactory.closeConnection(conn);
			return i;
		} catch (IOException e) {
			e.printStackTrace();
			System.out.println("creazione professore fallita");
			HsqldbDAOFactory.closeConnection(conn);
			return i;
		}
		HsqldbDAOFactory.closeConnection(conn);
		return i;
	}

	public void updateProfessore(ProfessoreTO professore) {
		Connection conn = HsqldbDAOFactory.createConnection();
		try {
			PreparedStatement add_stmt = conn.prepareStatement(HsqldbQuery.updateProf);
			// nome = ?, cognome = ?, matricola = ?, biografia = ?, fotoBytes =
			// ?, fotoContentType = ?, fotoName = ? WHERE id = ?";
			add_stmt.clearParameters();
			add_stmt.setString(1, professore.getNome());
			add_stmt.setString(2, professore.getCognome());
			add_stmt.setString(3, professore.getMatricola());
			add_stmt.setString(4, professore.getBiografia());
			add_stmt.setBytes(5, professore.getFotoBytes());
			add_stmt.setString(6, professore.getFotoContentType());
			add_stmt.setString(7, professore.getFotoName());
			add_stmt.setInt(8, professore.getId());
			add_stmt.executeUpdate();
			add_stmt.close();
		} catch (SQLException e) {
			e.printStackTrace();
			System.out.println("creazione professore fallita");
			HsqldbDAOFactory.closeConnection(conn);
			return;
		}
		HsqldbDAOFactory.closeConnection(conn);
	}

	public void delProfessore(Integer id) {
		Connection conn = HsqldbDAOFactory.createConnection();
		try {
			PreparedStatement add_stmt = conn.prepareStatement(HsqldbQuery.deleteProf);
			add_stmt.clearParameters();
			add_stmt.setInt(1, id);
			add_stmt.executeUpdate();
			add_stmt.close();
		} catch (SQLException e) {
			e.printStackTrace();
			System.out.println("distruzione professore fallita");
			HsqldbDAOFactory.closeConnection(conn);
			return;
		}
		HsqldbDAOFactory.closeConnection(conn);
	}

	// ----------------------------------------------------------------------------------------------

	/**
	 * Da eseguire prima della initTable dei corsi
	 */
	public void initTable() {
		Connection conn = HsqldbDAOFactory.createConnection();
		try {
			Statement stmt = conn.createStatement();
			stmt.execute(HsqldbQuery.dropTableProfessori);
			stmt.close();
		} catch (SQLException e) {
			e.printStackTrace();
			System.out.println("tabella professori non esiste");
		}
		try {
			Statement stmt = conn.createStatement();
			stmt.execute(HsqldbQuery.createTableProfessori);
			System.out.println("tabella professori creata");
			stmt.close();
		} catch (SQLException e) {
			e.printStackTrace(); 
			System.out.println("tabella professori esiste gia'"); 
		}
		HsqldbDAOFactory.closeConnection(conn);
	}

}
